/* Sailing - a GUI Animation Example
 * Bob Wilson
 * 11/26/2017
 * 
 * */

import java.awt.Container;
import java.awt.Graphics;
import java.awt.Color;

import javax.swing.JFrame;
import javax.swing.JPanel;

public class Sailing extends JFrame implements Runnable
{
  private int animationState = 0;
  
  public static void main(String[] args) 
  {
    // Get out of static context
    new Sailing().execute();
  }
  
  // Sailing constructor only needs to set title bar for its parent JFrame
  public Sailing()
  {
    super("Sailing");
  }
  
  // This is the rest of the main method - now out of static context
  private void execute()
  {
    // Set up the GUI Window
    Container cp = getContentPane();
    cp.add(new JPanel());
    setSize(700, 400);
    setVisible(true);
    
    // Now start the animation state machine in a separate thread
    new Thread(this).start();
    
    // The current thread is not blocked, we are free to do other things
    // If we had just called run() directly, it would never return (infinite loop)
    System.out.println("Done.");
  }
  
  public void run() {
    while (true) {                 // Loop until GUI frame is closed
      repaint();                      // Repaint the screen
      try {
        Thread.sleep(1000);           // Delay (in millisecs)
      }
      catch (Exception e) {
      }
      if (animationState < 9) {       // Update State Variable
        animationState++;
      }
      else {
        animationState = 0;
      }
    }
  }
  
  public void paint(Graphics screen) {
    screen.clearRect(0, 0, getWidth(), getHeight());
    screen.setColor(Color.RED);
    screen.drawString("Graphics and Animation by " +
                      "Bob Wilson", 400, 345);
    screen.setColor(Color.BLACK);
    
    if (animationState % 2 == 0) {
        drawWaves1(screen, 250);
        drawWaves2(screen, 270);
        drawWaves1(screen, 290);
        drawSailboat1(screen, 10 + 20 * animationState, 250);
    }
    else{
        drawWaves2(screen, 250);
        drawWaves1(screen, 270);
        drawWaves2(screen, 290);
        drawSailboat2(screen, 10 + 20 * animationState, 250);
    }
    
    switch (animationState) {
      case 0: 
      case 1:
      case 4:
      case 5:
        screen.drawString("Sailing ...", 400, 120);
        break;
      case 8:
      case 9:
        screen.drawString("Over the Bounding Main.", 400, 120);
        break;
    }
  }

  private void drawWaves1(Graphics screen, int y) {
    screen.setColor(Color.BLUE);
    screen.drawLine(10, y + 30 - 2 - 1, 60, y + 30 + 2 - 1);
    screen.drawLine(60, y + 30 + 2 - 1, 120, y + 30 - 2 - 1);
    screen.drawLine(120, y + 30 - 2 - 1, 180, y + 30 + 2 - 1);
    screen.drawLine(180, y + 30 + 2 - 1, 240, y + 30 - 2 - 1);
    screen.drawLine(240, y + 30 - 2 - 1, 300, y + 30 + 2 - 1);
    screen.drawLine(300, y + 30 + 2 - 1, 360, y + 30 - 2 - 1);
    screen.drawLine(360, y + 30 - 2 - 1, 420, y + 30 + 2 - 1);
    screen.drawLine(420, y + 30 + 2 - 1, 480, y + 30 - 2 - 1);
    screen.drawLine(480, y + 30 - 2 - 1, 540, y + 30 + 2 - 1);
    screen.drawLine(540, y + 30 + 2 - 1, 600, y + 30 - 2 - 1);
  }

  private void drawWaves2(Graphics screen, int y) {
    screen.setColor(Color.BLUE);
    screen.drawLine(10, y + 30 + 2 - 1, 10 + 60, y + 30 - 2 - 1);
    screen.drawLine(10 + 60, y + 30 - 2 - 1, 10 + 120, y + 30 + 2 - 1);
    screen.drawLine(10 + 120, y + 30 + 2 - 1, 10 + 180, y + 30 - 2 - 1);
    screen.drawLine(10 + 180, y + 30 - 2 - 1, 10 + 240, y + 30 + 2 - 1);
    screen.drawLine(10 + 240, y + 30 + 2 - 1, 10 + 300, y + 30 - 2 - 1);
    screen.drawLine(10 + 300, y + 30 - 2 - 1, 10 + 360, y + 30 + 2 - 1);
    screen.drawLine(10 + 360, y + 30 + 2 - 1, 10 + 420, y + 30 - 2 - 1);
    screen.drawLine(10 + 420, y + 30 - 2 - 1, 10 + 480, y + 30 + 2 - 1);
    screen.drawLine(10 + 480, y + 30 + 2 - 1, 10 + 540, y + 30 - 2 - 1);
    screen.drawLine(10 + 540, y + 30 - 2 - 1, 10 + 600, y + 30 + 2 - 1);
  }

  private void drawSailboat1(Graphics screen, int x, int y) {
    screen.setColor(Color.BLACK);
    screen.drawLine(x + 1, y - 2, x + 200 + 1, y + 2); //Deck
    screen.drawLine(x, y + 30 - 2, x + 170, y + 30 + 2); //Keel
    screen.drawLine(x + 1, y - 2, x, y + 30 - 2); //Transom
    screen.drawLine(x + 200 + 1, y + 2, x + 170, y + 30 + 2); //Bow
    screen.drawLine(x + 150 - 2, y, x + 150 + 2, y - 200); //Mast
    screen.drawLine(x + 150 - 2, y - 10, x + 25 - 2, y - 10 - 2); //Boom
    screen.drawLine(x + 25 - 2, y - 10 - 2, x + 150 + 2, y - 200); //Main
    screen.drawLine(x + 200 + 1, y + 2, x + 150 + 2, y - 160); //Jib
  }

  private void drawSailboat2(Graphics screen, int x, int y) {
    screen.setColor(Color.BLACK);
    screen.drawLine(x - 1, y + 2, x + 200 - 1, y - 2); //Deck
    screen.drawLine(x, y + 30 + 2, x + 170, y + 30 - 2); //Keel
    screen.drawLine(x - 1, y + 2, x, y + 30 + 2); //Transom
    screen.drawLine(x + 200 - 1, y - 2, x + 170, y + 30 - 2); //Bow
    screen.drawLine(x + 150 + 2, y, x + 150 - 2, y - 200); //Mast
    screen.drawLine(x + 150 + 2, y - 10, x + 25 - 2, y - 10 + 2); //Boom
    screen.drawLine(x + 25 - 2, y - 10 + 2, x + 150 - 2, y - 200); //Main
    screen.drawLine(x + 200 - 1, y - 2, x + 150 - 1, y - 160); //Jib
    
  }
}
